@@ -22,13 +22,13 @@ class PySiteConfiguration(object):
 		elif not getattr(self,'logfile',None):
 			self.logfile = join(self.basedir,'%s.log' % self.sitename)
 
-	def basedir_abspath(self):
+	def basedir_abspath(self,*args):
 		"""
 		Get the absolute path to the site base directory
 		
 		@rtype: string
 		"""
-		return self.basedir_a
+		return join(*((self.basedir_a,) + args))
 
 global_conf = None
 
