@@ -21,25 +21,27 @@ class HTTPRequestData(object):
 		
 	# Probe function
 	@staticmethod
-	def _probe_value(data,varname):
+	def _probe_value(data,varname,defval=None):
 		rx = re.compile('%s=([^&]+)' % varname)
 		for match in rx.finditer(data):
 			return match.group(1)
-		return None
+		return defval
 	
-	def get_post_value(self,varname):
-		return HTTPRequestData._probe_value(self.post_values,varname)
+	def get_post_value(self,varname,defval=None):
+		return HTTPRequestData._probe_value(self.post_values,varname,defval)
 	
-	def get_qs_value(self,varname):
-		return HTTPRequestData._probe_value(self.query_string,varname)
+	def get_qs_value(self,varname,defval=None):
+		return HTTPRequestData._probe_value(self.query_string,varname,defval)
 	
-	def get_cookie_value(self,varname):
-		return HTTPRequestData._probe_value(self.cookies,varname)
+	def get_cookie_value(self,varname,defval=None):
+		return HTTPRequestData._probe_value(self.cookies,varname,defval)
 
-	def get_any_value(self,varname):
+	def get_any_value(self,varname,defval=None):
 		val = self.get_post_value(varname)
-		if not val:
+		if val==None:
 			val = self.get_qs_value(varname)
-		if not val:
+		if val==None:
 			val = self.get_cookie_value(varname)
+		if val==None:
+			return defval
 		return val
