@@ -1,9 +1,6 @@
 import logging,logging.handlers
 import traceback,imp,sys
-if sys.version_info[0]==2:
-	from StringIO import StringIO
-elif sys.version_info[0]>=3:
-	from io import StringIO
+from pysite.compat import StringIO
 from os.path import join
 
 
