@@ -185,8 +185,11 @@ class PySiteApplication(object):
 			lang = None # Default
 			default_lang = 'en'
 			browser_langs = []
+			blang = None
 			if 'HTTP_ACCEPT_LANGUAGE' in environ:
 				browser_langs = httpheader.parse_accept_language_header(environ['HTTP_ACCEPT_LANGUAGE'])
+				if browser_langs:
+					blang = browser_langs[0]
 			for l in browser_langs:
 				if lang:
 					break
@@ -204,8 +207,11 @@ class PySiteApplication(object):
 				'tr':{},
 				'tr_common':{},
 				'sitename': self.conf.sitename,
-				'sitetitle': self.conf.sitetitle
+				'sitetitle': self.conf.sitetitle,
 			}
+			if blang:
+				template_info['browser_lang'] = blang[0].parts[0]
+			
 			template_info.update(locales.tr(lang,'common'))
 			template_info.update(locales.tr(lang,template))
 			template_info['tr_common'].update(locales.tr(lang,'common'))
@@ -227,13 +233,24 @@ class PySiteApplication(object):
 			environ['tr'] = locales.tr
 			environ['logger'] = log
 			environ['lang'] = lang
-			init = getattr(subhandler,'init',None)
-			if init:
+			init_args = (template_info,response_headers,environ,translate,req_data)
+			
+			template_off = False
+			shandler_class = getattr(subhandler,'subhandler',None)
+			shandler_instance = None
+			init = None
+			if shandler_class!=None:
+				shandler_instance = shandler_class(*init_args)
+			else:
+				init = getattr(subhandler,'init',None)
+			if shandler_instance or init:
 				try:
-					res = init(template_info,response_headers,environ,translate,req_data)
-					if type(res)==types.GeneratorType:
+					if shandler_instance:
+						res = shandler_instance.init()
+					else:
+						res = init(*init_args)
+					if getattr(res,'__iter__',None):
 						first_iter = True
-						template_off = False
 						for data in res:
 							if first_iter:
 								template_off = template_info.get("template_off",False)
@@ -244,7 +261,7 @@ class PySiteApplication(object):
 								yield data
 						if template_off:
 							raise StopIteration
-					elif type(res)==str:
+					elif type(res)==PORTABLE_BYTES:
 						template_off = template_info.get("template_off",False)
 						if template_off:
 							start_response(status, response_headers)
@@ -262,13 +279,14 @@ class PySiteApplication(object):
 					output = redirect(location,cookies,start_response)
 					raise StopIteration
 			
-			template_info['translate'] = translate
-			template = join(self.templates_dir,'%s.jinja' % template)
-			if exists(template):
-				jinja_temp = Template(PORTABLE_STRING(open(template,'rb').read(),'utf-8'))
-				output = jinja_temp.render(template_info).encode('utf-8')
-			else:
-				output = b'Template: "%s" does not exist' % template if type(template)==PORTABLE_BYTES else template.encode('utf-8')
+			if not template_off:
+				template_info['translate'] = translate
+				template = join(self.templates_dir,'%s.jinja' % template)
+				if exists(template):
+					jinja_temp = Template(PORTABLE_STRING(open(template,'rb').read(),'utf-8'))
+					output = jinja_temp.render(template_info).encode('utf-8')
+				else:
+					output = b'Template: "%s" does not exist' % template if type(template)==PORTABLE_BYTES else template.encode('utf-8')
 		except Exception as e:
 			if type(e)==StopIteration:
 				raise e
@@ -283,4 +301,3 @@ class PySiteApplication(object):
 		
 		start_response(status, response_headers)
 		yield output
-
